pub struct PlanModeExternalStatus {
pub session_id: String,
pub enabled: bool,
pub plan_path: Option<String>,
}Fields
session_id: Stringenabled: boolplan_path: Option<String>Trait Implementations
Sourceimpl Clone for PlanModeExternalStatus
impl Clone for PlanModeExternalStatus
Sourcefn clone(&self) -> PlanModeExternalStatus
fn clone(&self) -> PlanModeExternalStatus
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PlanModeExternalStatus
impl Debug for PlanModeExternalStatus
Sourceimpl Default for PlanModeExternalStatus
impl Default for PlanModeExternalStatus
Sourcefn default() -> PlanModeExternalStatus
fn default() -> PlanModeExternalStatus
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for PlanModeExternalStatus
impl<'de> Deserialize<'de> for PlanModeExternalStatus
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PlanModeExternalStatus
impl JsonSchema for PlanModeExternalStatus
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for PlanModeExternalStatus
impl RefUnwindSafe for PlanModeExternalStatus
impl Send for PlanModeExternalStatus
impl Sync for PlanModeExternalStatus
impl Unpin for PlanModeExternalStatus
impl UnsafeUnpin for PlanModeExternalStatus
impl UnwindSafe for PlanModeExternalStatus